@@ -34,12 +34,15 @@
 using namespace Konsole;
 
 Emulation::Emulation() :
+    _windows(QList<ScreenWindow *>()),
     _currentScreen(nullptr),
     _codec(nullptr),
     _decoder(nullptr),
     _keyTranslator(nullptr),
     _usesMouse(false),
     _bracketedPasteMode(false),
+    _bulkTimer1(new QTimer(this)),
+    _bulkTimer2(new QTimer(this)),
     _imageSizeInitialized(false)
 {
     // create screens with a default size
@@ -100,7 +103,7 @@ void Emulation::checkScreenInUse()
 
 void Emulation::checkSelectedText()
 {
-    QString text = _currentScreen->selectedText(true);
+    QString text = _currentScreen->selectedText(Screen::PreserveLineBreaks);
     emit selectionChanged(text);
 }
 
@@ -249,61 +252,17 @@ void Emulation::receiveData(const char *text, int length)
     //this check into the above for loop?
     for (int i = 0; i < length; i++) {
         if (text[i] == '\030') {
-            if ((length - i - 1 > 3) && (qstrncmp(text + i + 1, "B00", 3) == 0)) {
-                emit zmodemDetected();
+            if (length - i - 1 > 3) {
+                if (qstrncmp(text + i + 1, "B00", 3) == 0) {
+                    emit zmodemDownloadDetected();
+                } else if (qstrncmp(text + i + 1, "B01", 3) == 0) {
+                    emit zmodemUploadDetected();
+                }
             }
         }
     }
 }
 
-//OLDER VERSION
-//This version of onRcvBlock was commented out because
-//    a)  It decoded incoming characters one-by-one, which is slow in the current version of Qt (4.2 tech preview)
-//    b)  It messed up decoding of non-ASCII characters, with the result that (for example) chinese characters
-//        were not printed properly.
-//
-//There is something about stopping the _decoder if "we get a control code halfway a multi-byte sequence" (see below)
-//which hasn't been ported into the newer function (above).  Hopefully someone who understands this better
-//can find an alternative way of handling the check.
-
-/*void Emulation::onRcvBlock(const char *s, int len)
-{
-  emit notifySessionState(NOTIFYACTIVITY);
-
-  bufferedUpdate();
-  for (int i = 0; i < len; i++)
-  {
-
-    QString result = _decoder->toUnicode(&s[i],1);
-    int reslen = result.length();
-
-    // If we get a control code halfway a multi-byte sequence
-    // we flush the _decoder and continue with the control code.
-    if ((s[i] < 32) && (s[i] > 0))
-    {
-       // Flush _decoder
-       while(!result.length())
-          result = _decoder->toUnicode(&s[i],1);
-       reslen = 1;
-       result.resize(reslen);
-       result[0] = QChar(s[i]);
-    }
-
-    for (int j = 0; j < reslen; j++)
-    {
-      if (result[j].characterategory() == QChar::Mark_NonSpacing)
-         _currentScreen->compose(result.mid(j,1));
-      else
-         onRcvChar(result[j].unicode());
-    }
-    if (s[i] == '\030')
-    {
-      if ((len-i-1 > 3) && (qstrncmp(s+i+1, "B00", 3) == 0))
-          emit zmodemDetected();
-    }
-  }
-}*/
-
 void Emulation::writeToStream(TerminalCharacterDecoder *decoder, int startLine, int endLine)
 {
     _currentScreen->writeLinesToStream(decoder, startLine, endLine);
