@@ -7,12 +7,10 @@
 #define KONSOLE_WCWIDTH_H
 
 // Qt
-#include <QtCore/QString>
+#include <QString>
 
 int konsole_wcwidth(quint16 oucs);
-int konsole_wcwidth_cjk(quint16 oucs);
 
-int string_width(const QString& text);
-int string_width_cjk(const QString& text);
+int string_width(const QString &text);
 
 #endif
